function rate=evol_rate(id_trans,save_flag,flag_smooth,span)
% RATE=EVOL_RATE(ID_TRANS,FLAG_SAV,FLAG_SMOOTH,SPAN)
%   Plot the evolution of the estimated rate of the transition with id number ID_TRANS.
%   If SAVE_FLAG=1, save figure.
%   If SAVE_FLAG=2, save data.
%   If SAVE_FLAG=3, save figure and data.
%   If FLAG_SMOOTH is set, the data are smoothed over time using SPAN value.

if ~exist('save_flag','var')
  save_flag=0;
end

if ~exist('flag_smooth','var')
  flag_smooth=0;
end

%if ~exist('span','var')
  %span=10;
%end

%% read header of RATE.log
fprintf('reading RATE.log\n');
fid=fopen('RATE.log');
if (fid==-1)
  fprintf('file not found\n');
  return
end
textscan(fid,'# %[^\n]s');

%% read column headers
str_trans=textscan(fid,'%[^\n]s');
nb_trans=count(str_trans{1},"TR");
nc=nb_trans+1;

fprintf('total number of transitions: %d \n', nb_trans);

if id_trans > nb_trans-1
  fprintf('incorrect id: %d\n', id_trans);
  return;
end

%% read trans data
C=textscan(fid,'%f','delimiter',':');
data0=cell2mat(C);
l=size(data0,1);
nb=l/nc;
fprintf('number of records: %d\n', nb);
data=reshape(data0,nc,nb)';
rate=data(:,id_trans+2);
fclose(fid);

%% read time data
fprintf('reading TIME.log\n');
fid=fopen('TIME.log');
if (fid==-1)
  fprintf('file not found\n');
  return
end
C=textscan(fid,'%[^\n]s');
%celldisp(C)
C=textscan(fid,'%f','delimiter',':dhms');
data0=cell2mat(C);
l=size(data0,1);
nb=nb+1;
c=l/nb;
data=reshape(data0,c,nb)';
time0=data(1,4);
timedata=data(2:nb,4);
dtimedata=data(2:nb,5);
fclose(fid);

%keyboard

avg=mean(rate);
fprintf('Mean rate: %f\n', avg);

%% plot data
figure
hold on
lw=0.5;
title(sprintf('Mean rate of transition %d: %.3g t_0^{-1}', id_trans, avg))
if ~flag_smooth
  plot(timedata,rate,'linewidth',lw)
  plot(timedata,rate,'.')
else
  if ~exist('span','var')
    span=ceil(size(rate,1)/100);
  end
  fprintf('smooth rate on 2x%d records\n', span);
  rate_sm=smooth1(rate,span);
  plot(timedata,rate_sm,'linewidth',lw*2)
end
xlabel('Time (t_{0})')
ylabel('Estimated rate (t_{0}^{-1})')
grid on

if save_flag
  str_sm='';
  if flag_smooth
    str_sm=sprintf('_sm%d',span);
  end
  if bitand(save_flag,1)
    figname=sprintf('EVOL_RATE_%d%s.png',id_trans,str_sm);
    fprintf('save figure into file: %s\n',figname);
    print(figname,'-dpng','-r250');
  end
  if bitand(save_flag,2)
    filename=sprintf('EVOL_RATE_%d%s.out',id_trans,str_sm);
    fprintf('save data into file: %s\n',filename);
    data=[timedata rate];
    save(filename,'data','-ascii');
  end
end

return

