/* ReSCAL - Event scheduler whithin the simulation
 *
 * Copyright (C) 2021
 *
 * Author: Olivier Rozier <rozier@ipgp.fr>
 *
 * This file is part of ReSCAL.
 *
 * ReSCAL is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/// Max number of events per simulation
#define NB_EVT_MAX 100

/// Family of events
enum EVT_FAMILY {EF_GEN, EF_MODEL, EF_ALL};

/// Periodicity of events
enum EVT_PERIODICITY {EP_SINGLE, EP_REGULAR, EP_NON_REGULAR};


typedef struct event{
  int family;
  int type;
  char *name;
  int periodicity;
  int active;
  double delay;
  double time_threshold;
} Evt;

typedef struct event_scheduler{
  int family;
  char *name;
  int nb_events;
  double next_time_threshold;
  //double epsilon;
  Evt evt[NB_EVT_MAX];
} Evt_sched;


void schedul_init();
void schedul_add_event(int type, double evt_time);
void schedul_add_reg_event(int type, double delay, int offset);
void schedul_add_non_reg_event(int type, double t0);
void schedule_family(int evt_fam);
double get_next_time_threshold();
//int no_sched_events();
int get_nb_events(int fam);
int get_total_nb_events();
void schedul_reset_time_all();
